@@ -3,12 +3,12 @@ package ViolationFinder;
 use v5.26.0;
 use strict;
 use warnings;
+use feature "signatures";
+use experimental "signatures";
 
-use Exporter     qw( import );
-use PPI          ();
-use Test2::V0    qw( fail is like );
-use feature      qw( signatures );
-use experimental qw( signatures );
+use Exporter  qw( import );
+use PPI       ();
+use Test2::V0 qw( fail is like );
 
 our @EXPORT_OK = qw( find_violations count_violations good bad );
 
